pub struct L2capChannelOffloadParameters {
pub acl_connection_handle: Option<u16>,
pub local_l2cap_channel_id: Option<u16>,
pub remote_l2cap_channel_id: Option<u16>,
pub local_l2cap_maximum_payload_size: Option<u16>,
pub remote_l2cap_maximum_payload_size: Option<u16>,
pub initial_tx_credits: Option<u16>,
/* private fields */
}Expand description
Set of low-level L2CAP channel parameters needed to transfer control of a channel to an offload processor.
Fields
acl_connection_handle: Option<u16>The HCI ACL connection handle to the peer over which this L2CAP channel exists. Required.
local_l2cap_channel_id: Option<u16>Required.
remote_l2cap_channel_id: Option<u16>Required.
local_l2cap_maximum_payload_size: Option<u16>The maximum payload size of a RX L2CAP PDU, not to be confused with the MTU of application layer payloads. Required.
remote_l2cap_maximum_payload_size: Option<u16>The maximum paylod size of a TX L2CAP PDU, not to be confused with the MTU of application layer payloads. Required.
initial_tx_credits: Option<u16>The initial number of TX flow control credits received from the peer. Optional. Not present for channels without flow control.